// import { ChevronUpIcon } from '@chakra-ui/icons'
import { Avatar, Box, Button, Fade, Flex, Image, Text } from '@chakra-ui/react'
import moment from 'moment'
import React from 'react'

const CardDeatil = ({ data }: { data: any }) => {
    return (
        <>
            <Box border="1px" p={3} rounded="20px" mt="120px">
                <Flex gap={2} alignItems="center" w="100%">
                    <Flex
                        flexDirection="row"
                        alignItems="center"
                        w="100%"
                        gap={2}
                        cursor="pointer"
                    >
                        <Avatar name={data?.created_by?.first_name} size="sm" />
                        <Text fontSize="lg" fontWeight="bold" textTransform="uppercase">
                            {data?.created_by?.first_name} {data?.created_by?.last_name ?? ''} | {data?.full_name}
                        </Text>
                        <Box ms="auto">
                            {/* <ChevronUpIcon width="20px" height="20px" /> */}
                        </Box>
                    </Flex>
                </Flex>
                <Fade in >
                    <Box py="1" mt={3} px={0} rounded="md">
                        <Flex rowGap={1} alignItems="center" flexWrap="wrap" justifyContent="space-between">
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Contact Info: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.contact_information}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Address: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.address}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    GIS Tagging: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.gis_tagging}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Contract No / Consumer No: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.contract_no_or_consumer_no}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Meter No: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.meter_no}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Additional Meter Requirement: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.additional_meter ? "Planned" : "Un-Planned"}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Premises In Use: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.premises_in_use == 1 ? 'Yes' : 'No'}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Meter Exist On Site: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.meter_exist_on_site == 1 ? 'Yes' : 'No'}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Premises Type: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.premises_type}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Property Type: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.property_type}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Meter Installed: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.meters_installed ? 'Yes' : 'No'}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Additional Meter Req: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.additional_meter_req == 1 ? 'Yes' : 'No'}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold" sx={{ textTransform: "capitalized" }}>
                                    Additional Meter Applied: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {data?.additional_meter_applied == 1 ? 'Yes' : 'No'}
                                    </Text>
                                </Text>
                            </Box>
                            <Box width="50%">
                                <Text fontSize="sm" fontWeight="bold">
                                    Created At: &nbsp;
                                    <Text as="span" fontWeight="normal">
                                        {moment(data?.created_at).fromNow()}
                                    </Text>
                                </Text>
                            </Box>
                            {data?.attachments?.length > 0 && (
                            <Box width="100%">
                                <Text fontSize="sm" fontWeight="bold">
                                    Attachments: &nbsp;

                                    {data?.attachments?.map((attachment: any, index: number) => (
                                        <Image
                                            key={index}
                                            src={attachment?.file?.link}
                                            alt="attachment"
                                            boxSize="200px"
                                            mt="10px"
                                            objectFit="contain"
                                        />
                                    ))}
                                </Text>
                            </Box>)}
                        </Flex>
                    </Box>
                </Fade>

                {data?.offline && (
                    <Flex columnGap={1} alignItems="center" mt="6">
                        <Button size="sm" px="3" >
                            Upload
                        </Button>
                    </Flex>
                )}


            </Box>
        </>
    )
}

export default CardDeatil